<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

/**
 * WPCasa_Legacy_Admin class
 */
class WPCasa_Legacy_Admin {

	/**
	 * Constructor
	 */
	public function __construct() {
		
		// Include classes
		include_once WPSIGHT_LEGACY_PLUGIN_DIR . '/includes/admin/class-wpcasa-legacy-cpt.php';
		
		// Init classes
		$this->cpt = new WPCasa_Legacy_Admin_CPT();
		
		// Actions
		
		add_action( 'init', array( $this, 'check_gallery_upgrade' ) );
		add_action( 'init', array( $this, 'check_location_upgrade' ) );
		add_action( 'init', array( $this, 'check_agent_info_upgrade' ) );

	}
	
	/**
	 *	check_gallery_upgrade()
	 *	
	 *	Helper function to run image
	 *	gallery update on all listings.
	 *	
	 *	@uses	wpsight_get_option()
	 *	@uses	get_posts()
	 *	@uses	wpsight_post_type()
	 *	@uses	get_post_stati()
	 *	@uses	wpsight_maybe_update_gallery()
	 *	@uses	wpsight_add_option()
	 *	
	 *	@since 1.0.0
	 */
	public function check_gallery_upgrade() {

		// run the upgrade only once per site

		if ( false === wpsight_get_option( 'legacy_gallery_upgraded', false ) ) {

			$listings = get_posts( array( 
				'posts_per_page'	=> true, 
				'post_type'			=> wpsight_post_type(), 
				'post_status'		=> get_post_stati(),
				'fields'			=> 'ids'
			) );

			foreach ( $listings as $listing_id ) {

				// Update with attachments
				wpsight_maybe_update_gallery( $listing_id );
				
				// Update with _images post meta

				$images = get_post_meta( $listing_id, '_images' );
				
				if( $images && is_array( $images ) ) {
					
					$gallery = get_post_meta( $listing_id, '_gallery', true );
					
					$new_gallery = array();
					
					foreach( $images as $image )
						$new_gallery[ $image ] = wp_get_attachment_url( $image );
					
					if( ! empty( $new_gallery ) && ! $gallery )
						update_post_meta( $listing_id, '_gallery', $new_gallery );
					
				}

			}
			
			// save the option for future checks
			wpsight_add_option( 'legacy_gallery_upgraded', true );

		}
		
	}
	
	/**
	 *	check_location_upgrade()
	 *
	 *	Helper function to run location
	 *	data update on all listings.
	 *
	 *	@uses	wpsight_get_option()
	 *	@uses	get_posts()
	 *	@uses	wpsight_post_type()
	 *	@uses	get_post_stati()
	 *	@uses	get_post_meta()
	 *	@uses	update_post_meta()
	 *	@uses	WPSight_Geocode::get_location_data()
	 *	@uses	is_wp_error()
	 *	@uses	wp_remote_get()
	 *	@uses	wp_remote_retrieve_body()
	 *	@uses	json_decode()
	 *	@uses	WPSight_Geocode::has_location_data()
	 *	@uses	WPSight_Geocode::generate_location_data()
	 *	@uses	wpsight_add_option()
	 *
	 *	@since 1.0.0
	 */
	public function check_location_upgrade() {

		// run the upgrade only once per site

		if ( false === wpsight_get_option( 'legacy_location_upgraded', false ) ) {

			$listings = get_posts( array( 
				'posts_per_page'	=> true, 
				'post_type'			=> wpsight_post_type(), 
				'post_status'		=> get_post_stati(),
				'fields'			=> 'ids'
			) );

			foreach ( $listings as $listing_id ) {
				
				// Get map address
				$map_address = get_post_meta( $listing_id, '_map_address', true );
				
				// If empty, try _map_location
				
				if( empty( $map_address ) ) {
					$map_address = get_post_meta( $listing_id, '_map_location', true );
					if( ! empty( $map_address ) )
						update_post_meta( $listing_id, '_map_address', $map_address );
				}
				
				// If empty, try _map_geo
				
				if( empty( $map_address ) ) {
					$map_address = get_post_meta( $listing_id, '_map_geo', true );
					if( ! empty( $map_address ) )
						update_post_meta( $listing_id, '_map_address', $map_address );					
				}
				
				// If still empty, give up
				
				if( empty( $map_address ) )
					continue;
				
				// Check if we can get address already
				$address_data = WPSight_Geocode::get_location_data( $map_address );
				
				// If not try to get address by latlng
				
				if( is_wp_error( $address_data ) ) {
				
					$result = wp_remote_get(
						'http://maps.googleapis.com/maps/api/geocode/json?latlng=' . $map_address . '&sensor=false',
						array(
							'timeout'     => 5,
						    'redirection' => 1,
						    'httpversion' => '1.1',
						    'user-agent'  => 'WordPress/' . WPSIGHT_NAME . '-' . WPSIGHT_VERSION . '; ' . get_bloginfo( 'url' ),
						    'sslverify'   => false
					    )
					);
					
					$result		= wp_remote_retrieve_body( $result );
					$geocoded	= json_decode( $result );
					
					// If we get result, use it
					
					if( 'OK' == $geocoded->status )
						$map_address = sanitize_text_field( $geocoded->results[0]->formatted_address );
				
				}
				
				if( ! WPSight_Geocode::has_location_data( $listing_id ) && $map_address )
					WPSight_Geocode::generate_location_data( $listing_id, $map_address );
				
			}
			
			// save the option for future checks
			wpsight_add_option( 'legacy_location_upgraded', true );

		}
		
	}
	
	/**
	 *	check_agent_info_upgrade()
	 *	
	 *	Helper function to run agent
	 *	info update on all users.
	 *	
	 *	@uses	wpsight_get_option()
	 *	@uses	get_users()
	 *	@uses	get_user_meta()
	 *	@uses	wp_check_filetype()
	 *	@uses	wp_upload_dir()
	 *	@uses	wp_insert_attachment()
	 *	@uses	wp_generate_attachment_metadata()
	 *	@uses	wp_update_attachment_metadata()
	 *	@uses	update_user_meta()
	 *	@uses	wpsight_add_option()
	 *	
	 *	@since 1.0.0
	 */
	public function check_agent_info_upgrade() {

		// run the upgrade only once per site

		if ( false === wpsight_get_option( 'legacy_agent_info_upgraded', false ) ) {

			$users = get_users( array(
				'fields' => 'ids'
			) );
			
			foreach ( $users as $user_id ) {
				
				$profile_image = get_user_meta( $user_id, 'profile_image', true );
				
				if( $profile_image && is_array( $profile_image ) ) {
					
					// Get the path to a file in the upload directory
					$filename = $profile_image['url'];
					
					// Check the type of file
					$filetype = wp_check_filetype( basename( $filename ), null );
					
					// Get the path to the upload directory
					$wp_upload_dir = wp_upload_dir();
					
					// Prepare an array of post data for the attachment

					$attachment = array(
						'guid'           => $wp_upload_dir['url'] . '/' . basename( $filename ), 
						'post_mime_type' => $filetype['type'],
						'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $filename ) ),
						'post_content'   => '',
						'post_status'    => 'inherit'
					);
					
					// Insert the attachment
					$attachment_id = wp_insert_attachment( $attachment, $filename, 0 );
					
					// Make sure that this file is included, as wp_generate_attachment_metadata() depends on it
					require_once( ABSPATH . 'wp-admin/includes/image.php' );
					
					// Generate the metadata for the attachment and update the database record

					$attachment_data = wp_generate_attachment_metadata( $attachment_id, $filename );
					wp_update_attachment_metadata( $attachment_id, $attachment_data );
					
					// Finally update the user meta with the new image
					
					update_user_meta( $user_id, 'agent_logo', $filename );
					update_user_meta( $user_id, 'agent_logo_id', $attachment_id );
					
				}
			
			}
			
			// save the option for future checks
			wpsight_add_option( 'legacy_agent_info_upgraded', true );

		}
		
	}

}
