<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) )
	exit;

/**
 * WPCasa_Legacy_Filters class
 */
class WPCasa_Legacy_Filters {

	/**
	 * Constructor
	 */
	public function __construct() {
		
		add_filter( 'wpsight_get_listing_offer', array( $this, 'get_listing_offer' ), 10, 3 );
		add_filter( 'wpsight_meta_box_listing_price_fields', array( $this, 'listing_price_fields' ) );
		add_filter( 'wpsight_get_search_fields', array( $this, 'get_search_fields' ) );		
		add_filter( 'wpsight_get_listings_query_args', array( $this, 'listings_query_args' ) );
		
		// Ensure backward compatibility with old filters
		
		add_filter( 'wpsight_get_search_fields', array( $this, 'search_fields' ) );
		add_filter( 'wpsight_offers', array( $this, 'offers' ) );
		add_filter( 'wpsight_details', array( $this, 'details' ) );
		add_filter( 'wpsight_measurements', array( $this, 'measurements' ) );
		add_filter( 'wpsight_get_listing_price', array( $this, 'listing_price' ) );

	}
	
	/**
	 *	get_listing_offer()
	 *	
	 *	Return listings offer (e.g. sale, rent).
	 *	
	 *	@param	integer	$post_id Post ID
	 *	@param	bool	$label Optionally return offer key
	 *	@uses	get_the_ID()
	 *	@uses	get_post_meta()
	 *	@uses	wpsight_offers()
	 *	@return	string Offer label or key
	 *	
	 *	@since 1.0.0
	 */
	public function get_listing_offer( $offer, $post_id, $label ) {

		// Use global post ID if not defined

		if ( ! $post_id )
			$post_id = get_the_ID();

		// Get listing offer
		$offer = get_post_meta( $post_id, '_price_status', true );

		// False if no value
		if ( empty( $offer ) )
			return false;

		// Return label if desired

		if ( $label === true ) {

			// Get all offers
			$offers = wpsight_offers();

			// Set offer label
			$offer = $offers[$offer];

		}

		// Return offer key or label
		return $offer;

	}
	
	/**
	 *	listing_price_fields()
	 *	
	 *	Filters listing price meta box fields and
	 *	sets _price_status instead of _price_offer.
	 *	
	 *	@param	array	$fields	Registered meta box fields
	 *	@return	array	$fields Updated meta box fields
	 *	
	 *	@since 1.0.0
	 */
	public function listing_price_fields( $fields ) {		
		$fields['offer']['id'] = '_price_status';		
		return $fields;		
	}
	
	/**
	 *	get_search_fields()
	 *	
	 *	Filters search fields and replaces
	 *	listing-type with property-type taxonomy.
	 *	
	 *	@param	array	$fields	Registered search fields
	 *	@return	array	$fields Updated search fields
	 *	
	 *	@since 1.0.0
	 */
	public function get_search_fields( $fields ) {		
		
		unset( $fields['listing-type'] );
		
		$fields['property-type'] = array(
			'data' 			=> array(
				'taxonomy'			=> 'property-type',
		    	'show_option_none' 	=> __( 'Type', 'wpcasa' ),
		    	'option_none_value' => '',
		    	'hierarchical'		=> 1,
		    	'orderby'         	=> 'ID', 
				'order'           	=> 'ASC'
			),
			'type' 			=> 'taxonomy_select',
			'class'			=> 'width-1-5',
			'priority'		=> 50
		);
		
		return $fields;

	}
	
	/**
	 *	listings_query_args()
	 *	
	 *	Make sure search for offer
	 *	works with _price_status post meta
	 *	instead of _price_offer.
	 *	
	 *	@since 1.0.0
	 */
	public function listings_query_args( $args ) {
			
		if( isset( $args['meta_query']['offer'] ) )
			$args['meta_query']['offer']['key'] = '_price_status';
		
		return $args;

	}
	
	/**
	 *	search_fields()
	 *	
	 *	Backward compatibility for
	 *	wpsight_search_form_details filter.
	 *	
	 *	@since 1.0.0
	 */
	public function search_fields( $fields ) {		
		return apply_filters( 'wpsight_search_form_details', $fields );		
	}
	
	/**
	 *	offers()
	 *	
	 *	Backward compatibility for
	 *	wpsight_listing_statuses filter.
	 *	
	 *	@since 1.0.0
	 */
	public function offers( $offers ) {		
		return apply_filters( 'wpsight_listing_statuses', $offers );		
	}
	
	/**
	 *	details()
	 *	
	 *	Backward compatibility for
	 *	wpsight_standard_details and
	 *	wpsight_wpcasa_standard_details filter.
	 *	
	 *	@since 1.0.0
	 */
	public function details( $details ) {		
		return apply_filters( 'wpsight_wpcasa_standard_details', apply_filters( 'wpsight_standard_details', $details ) );		
	}
	
	/**
	 *	measurements()
	 *	
	 *	Backward compatibility for
	 *	wpsight_measurement_units filter.
	 *	
	 *	@since 1.0.0
	 */
	public function measurements( $measurements ) {
		return apply_filters( 'wpsight_measurement_units', $measurements );
	}
	
	/**
	 *	listing_price()
	 *	
	 *	Backward compatibility for
	 *	listing_price filter.
	 *	
	 *	@since 1.0.0
	 */
	public function listing_price( $price ) {
		return apply_filters( 'wpsight_listing_price', $price );
	}

}
